/*
 *                  IFS Research & Development
 *
 * This program is protected by copyright law and by international
 * conventions. All licensing, renting, lending or copying (including
 * for private use), and all other use of the program, which is not
 * expressively permitted by IFS Research & Development (IFS), is a
 * violation of the rights of IFS. Such violations will be reported to the
 * appropriate authorities.
 *
 * VIOLATIONS OF ANY COPYRIGHT IS PUNISHABLE BY LAW AND CAN LEAD
 * TO UP TO TWO YEARS OF IMPRISONMENT AND LIABILITY TO PAY DAMAGES.
 */

import ifs.fnd.base.IfsException;
import ifs.fnd.connect.xml.BinaryTransformer;

/**
 * Example Binary Transformer.
 *
 * IMPORTANT !!!
 * Do not place this class inside a package. It should be
 * in the default package.
 *
 * This example class implement the ifs.fnd.connect.xml.BinaryTransformer
 * interface that defines two methods: init() and transforem().
 * This interface is for transformation of binary data in form of byte array.
 *
 * The example shows how to create a single class transformer.
 * The final class file is created to the subdirectory 'bild' and from there
 * can be loaded in Setup IFS Connect feature in Solution Manager.
 * See build.xml for building details.
 *
 * The example manipulates the attached red.bmp image.
 *
 * @author japase
 */
public class MyBinaryTransformer implements BinaryTransformer {

   /**
    * Initialization that is performed once when the transformer class is loaded.
    * @throws IfsException
    */
   @Override
   public void init() throws IfsException {
   }

   /**
    * Transform a byte array to another byte array.
    * Note that the framework will create a new instance
    * each time transformation occurs.
    * This simple example works on the attached to the project
    * image (red.bmp) by manipulating the color in a part of the image.
    * @param data  binary data to be transformed
    * @return      binary data after transformation
    * @throws IfsException
    */
   @Override
   public byte[] transform(byte[] data) throws IfsException {

      for(int i=0; i<data.length/2; i++) {
         if(data[i]==36 || data[i]==28)
            data[i] = 119;
      }
      return data;
   }
}
